{**********************************************************}
{                                                          }
{          BLUE CODE for Delphi                            }
{                                                          }
{          Copyright (c) 1996-97 BlueCodeX                 }
{                                                          }
{**********************************************************}

unit CbGrMain;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, StdCtrls, Grids, NewGrids, ExtCtrls, Buttons;

type
  TForm1 = class(TForm)
    ComboBoxGrid1: TComboBoxGrid;
    Memo1: TMemo;
    Memo2: TMemo;
    Memo3: TMemo;
    Label1: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    Label4: TLabel;
    Label5: TLabel;
    DemoExeBtn: TSpeedButton;
    HelpBtn: TBitBtn;
    FontDialog1: TFontDialog;
    Image1: TImage;
    Bevel1: TBevel;
    Bevel2: TBevel;
    procedure FormCreate(Sender: TObject);
    procedure ComboBoxGrid1SelCellChange(Sender: TObject;
      ASelection: TGridRect);
    procedure ComboBoxGrid1Dialog(Sender: TObject; ACol, ARow: Longint);
    procedure ComboBoxGrid1DropDown(Sender: TObject; ACol, ARow: Longint);
    procedure ComboBoxGrid1CloseUp(Sender: TObject; ACol, ARow: Longint);
    procedure ComboBoxGrid1SelCellChanging(Sender: TObject;
      ASelection: TGridRect);
    procedure ComboBoxGrid1KeyPress(Sender: TObject; var Key: Char);
    procedure HelpBtnClick(Sender: TObject);
    procedure DemoExeBtnClick(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
  private
    { Private-Deklarationen }
    procedure SetMemoColor(Index: Integer);
    procedure SetMemoFont(Index: Integer);
    procedure SetMemoWordWrap(Index: Integer);
  public
    { Public-Deklarationen }
  end;

var
  Form1: TForm1;

implementation

{$R *.DFM}

uses DemoHelp, DemoExec, DemConst;

const
  ColorRow    = 1;
  FontRow     = 2;
  WordWrapRow = 3;

var
  Memos: array[0..2] of TMemo;
  WordWraps, Colors: TStrings;


procedure TForm1.ComboBoxGrid1SelCellChanging(Sender: TObject;
  ASelection: TGridRect);
begin
  if ASelection.Top = WordWrapRow then SetMemoWordWrap(ASelection.Left)
  else if ASelection.Top = FontRow then SetMemoFont(ASelection.Left);
end;

procedure TForm1.ComboBoxGrid1SelCellChange(Sender: TObject;
  ASelection: TGridRect);
begin
  with ComboBoxGrid1 do
    if LastSelection.Top <> ASelection.Top then
      Case ASelection.Top of
        ColorRow   : ComboStyle := gsDropDownList;
        FontRow    : ComboStyle := gsDialog;
        WordWrapRow: ComboStyle := gsDropDown;
      end;
end;

procedure TForm1.ComboBoxGrid1Dialog(Sender: TObject; ACol, ARow: Longint);
begin
  If FontDialog1.Execute then
  begin
    Memos[ACol - 1].Font := FontDialog1.Font;
    ComboBoxGrid1.Cells[ ACol, FontRow] := FontDialog1.Font.Name;
  end;
end;

procedure TForm1.ComboBoxGrid1DropDown(Sender: TObject; ACol,
  ARow: Longint);
begin
  with ComboBoxGrid1 do
    if ARow = ColorRow then ComboItems := Colors
    else ComboItems := WordWraps;
end;

procedure TForm1.ComboBoxGrid1CloseUp(Sender: TObject; ACol,
  ARow: Longint);
begin
  if ARow = ColorRow then SetMemoColor(ACol) else SetMemoWordWrap(ACol);
end;

procedure TForm1.SetMemoFont(Index: Integer);
begin
  with ComboBoxGrid1 do
    if Screen.Fonts.IndexOf(Cells[Index, FontRow]) <> -1 then
      Memos[Index - 1].Font.Name := Cells[Index, FontRow]
    else Cells[Index, FontRow] := Memos[Index - 1].Font.Name;
end;

procedure TForm1.SetMemoColor(Index: Integer);
begin
  with ComboBoxGrid1, Colors do
    if ComboItemIndex <> -1 then
      Memos[Index - 1].Color := TColor(Objects[ComboItemIndex])
    else Cells[Index, ColorRow] := Colors[IndexOfObject(
      Pointer(Memos[Index - 1].Color))];
end;

procedure TForm1.SetMemoWordWrap(Index: Integer);
var
  I: Integer;
begin
  with ComboBoxGrid1, WordWraps do
  begin
    I := IndexOf(Cells[Index, WordWrapRow]);
    if I <> -1 then Memos[Index - 1].WordWrap := Boolean(Objects[I])
    else Cells[Index, WordWrapRow] := WordWraps[IndexOfObject(
      Pointer(Memos[Index - 1].WordWrap))]
  end;
end;

procedure TForm1.ComboBoxGrid1KeyPress(Sender: TObject; var Key: Char);
begin
  if Key = #13 then
    with ComboBoxGrid1 do
      if Selection.Top = FontRow then SetMemoFont(Selection.Left)
      else if Selection.Top = WordWrapRow then SetMemoWordWrap(Selection.Left);
end;

procedure TForm1.HelpBtnClick(Sender: TObject);
begin
  Application.HelpJump(LoadStr(SBlueCodeHelpPfx) + TComboBoxGrid.Classname +
    LoadStr(SHelpComponentSfx));
end;

procedure TForm1.DemoExeBtnClick(Sender: TObject);
begin
  with Sender as TSpeedButton do
  begin
    if Tag = 0 then
    begin
      Tag := Longint(MakeDemoExecInfo(SColSGrDemoDir, SColSGrDemoExeName,
        SColSGrDemoCaption));
      { Programm nicht gefunden }
      if PDemoExecInfo(Tag)^.Path[0] = #0 then Exit;
    end;
    BlcDemoExec(PDemoExecInfo(Tag));
  end;
end;

procedure TForm1.FormCreate(Sender: TObject);
const
  ColorsArray: array[0..8] of TColor = ( clWhite, clRed, clGreen,
  clBlue, clGray, clYellow, clMaroon, clTeal, clPurple);
var
  I, J: Integer;
begin
  InitHelp;
  Application.HelpFile := LoadStr(SBlueCodeHelp);

  WordWraps := TStringList.Create;
  with WordWraps do
  begin
    AddObject(LoadStr(SCbGrDemoBool0), Pointer(True));
    AddObject(LoadStr(SCbGrDemoBool1), Pointer(False));
  end;

  Colors := TStringList.Create;
  for I := Low(ColorsArray) to High(ColorsArray) do
    Colors.AddObject((ColorToString(ColorsArray[I])), Pointer(ColorsArray[i]));
  { Wurde WordWrap schon zur Entwurfszeit auf True gesetzt, so springt der
    Text nicht mehr zurck, wenn WordWrap auf False gesetzt wird. In der
    DFM-Datei werden dann die durch WordWrap erzeugten Zeilenumbrche mit
    gespeichert. }
  Memo1.WordWrap := True;
  Memo3.WordWrap := True;
  Memos[0] := Memo1;
  Memos[1] := Memo2;
  Memos[2] := Memo3;

  with ComboBoxGrid1 do
  begin
    Cells[0, ColorRow]    := LoadStr(SCbGrDemoRow1);
    Cells[0, FontRow]     := LoadStr(SCbGrDemoRow2);
    Cells[0, WordWrapRow] := LoadStr(SCbGrDemoRow3);
    for J := 1 to 3 do
    begin
      SetMemoColor(J);
      SetMemoFont(J);
      SetMemoWordWrap(J);
      Cells[J, 0] := Memos[J - 1].Name;
    end;
  end;
end;

procedure TForm1.FormDestroy(Sender: TObject);
begin
  FreeHelp;
end;

end.


